@@ -4,12 +4,12 @@
 
 #pragma once
 
-#include <wpi/ArrayRef.h>
 #include <wpi/SmallVector.h>
+#include <wpi/span.h>
 
 namespace frc2 {
 template <typename T>
-void SetInsert(wpi::SmallVectorImpl<T>& vector, wpi::ArrayRef<T> toAdd) {
+void SetInsert(wpi::SmallVectorImpl<T>& vector, wpi::span<T> toAdd) {
   for (auto addCommand : toAdd) {
     bool exists = false;
     for (auto existingCommand : vector) {
